@@ -5,9 +5,8 @@
 package v1alpha1
 
 import (
-	"crypto/tls"
-	stdx509 "crypto/x509"
 	"fmt"
+	"net/netip"
 	"os"
 	"slices"
 	"strings"
@@ -26,6 +25,7 @@ import (
 	"github.com/siderolabs/talos/pkg/machinery/config/config"
 	"github.com/siderolabs/talos/pkg/machinery/config/machine"
 	"github.com/siderolabs/talos/pkg/machinery/constants"
+	"github.com/siderolabs/talos/pkg/machinery/nethelpers"
 	"github.com/siderolabs/talos/pkg/machinery/resources/block"
 )
 
@@ -197,15 +197,6 @@ func (m *MachineConfig) Network() config.MachineNetwork {
 	return m.MachineNetwork
 }
 
-// Time implements the config.Provider interface.
-func (m *MachineConfig) Time() config.Time {
-	if m.MachineTime == nil {
-		return &TimeConfig{}
-	}
-
-	return m.MachineTime
-}
-
 // Controlplane implements the config.Provider interface.
 func (m *MachineConfig) Controlplane() config.MachineControlPlane {
 	if m.MachineControlPlane == nil {
@@ -317,11 +308,6 @@ func (m *MachineConfig) CertSANs() []string {
 	return m.MachineCertSANs
 }
 
-// Registries implements the config.Provider interface.
-func (m *MachineConfig) Registries() config.Registries {
-	return &m.MachineRegistries
-}
-
 // SystemDiskEncryption implements the config.Provider interface.
 func (m *MachineConfig) SystemDiskEncryption() config.SystemDiskEncryption {
 	if m.MachineSystemDiskEncryption == nil {
@@ -471,6 +457,59 @@ func (k *KubeletNodeIPConfig) ValidSubnets() []string {
 	return k.KubeletNodeIPValidSubnets
 }
 
+// RegistryMirrorConfigs returns a map of registry mirror configurations.
+func (c *Config) RegistryMirrorConfigs() map[string]config.RegistryMirrorConfig {
+	if c == nil || c.MachineConfig == nil {
+		return nil
+	}
+
+	result := make(map[string]config.RegistryMirrorConfig, len(c.MachineConfig.MachineRegistries.RegistryMirrors))
+
+	for k, v := range c.MachineConfig.MachineRegistries.RegistryMirrors {
+		result[k] = v
+	}
+
+	return result
+}
+
+// RegistryAuthConfigs returns a map of registry authentication configurations.
+func (c *Config) RegistryAuthConfigs() map[string]config.RegistryAuthConfig {
+	if c == nil || c.MachineConfig == nil {
+		return nil
+	}
+
+	result := make(map[string]config.RegistryAuthConfig, len(c.MachineConfig.MachineRegistries.RegistryConfig))
+
+	for k, v := range c.MachineConfig.MachineRegistries.RegistryConfig {
+		if v.RegistryAuth == nil {
+			continue
+		}
+
+		result[k] = v.RegistryAuth
+	}
+
+	return result
+}
+
+// RegistryTLSConfigs returns a map of registry TLS configurations.
+func (c *Config) RegistryTLSConfigs() map[string]config.RegistryTLSConfig {
+	if c == nil || c.MachineConfig == nil {
+		return nil
+	}
+
+	result := make(map[string]config.RegistryTLSConfig, len(c.MachineConfig.MachineRegistries.RegistryConfig))
+
+	for k, v := range c.MachineConfig.MachineRegistries.RegistryConfig {
+		if v.RegistryTLS == nil {
+			continue
+		}
+
+		result[k] = v.RegistryTLS
+	}
+
+	return result
+}
+
 type registryEndpointWrapper struct {
 	endpoint     string
 	overridePath bool
@@ -495,35 +534,6 @@ func (r *RegistriesConfig) Mirrors() map[string]config.RegistryMirrorConfig {
 	return mirrors
 }
 
-// Config implements the Registries interface.
-func (r *RegistriesConfig) Config() map[string]config.RegistryConfig {
-	registries := make(map[string]config.RegistryConfig, len(r.RegistryConfig))
-
-	for k, v := range r.RegistryConfig {
-		registries[k] = v
-	}
-
-	return registries
-}
-
-// TLS implements the Registries interface.
-func (r *RegistryConfig) TLS() config.RegistryTLSConfig {
-	if r.RegistryTLS == nil {
-		return nil
-	}
-
-	return r.RegistryTLS
-}
-
-// Auth implements the Registries interface.
-func (r *RegistryConfig) Auth() config.RegistryAuthConfig {
-	if r.RegistryAuth == nil {
-		return nil
-	}
-
-	return r.RegistryAuth
-}
-
 // Username implements the Registries interface.
 func (r *RegistryAuthConfig) Username() string {
 	return r.RegistryUsername
@@ -559,41 +569,6 @@ func (r *RegistryTLSConfig) InsecureSkipVerify() bool {
 	return pointer.SafeDeref(r.TLSInsecureSkipVerify)
 }
 
-// GetTLSConfig prepares TLS configuration for connection.
-func (r *RegistryTLSConfig) GetTLSConfig() (*tls.Config, error) {
-	tlsConfig := &tls.Config{}
-
-	if r.TLSClientIdentity != nil {
-		cert, err := tls.X509KeyPair(r.TLSClientIdentity.Crt, r.TLSClientIdentity.Key)
-		if err != nil {
-			return nil, fmt.Errorf("error parsing client identity: %w", err)
-		}
-
-		tlsConfig.Certificates = []tls.Certificate{cert}
-	}
-
-	if r.CA() != nil {
-		tlsConfig.RootCAs = stdx509.NewCertPool()
-		tlsConfig.RootCAs.AppendCertsFromPEM(r.TLSCA)
-	}
-
-	if r.InsecureSkipVerify() {
-		tlsConfig.InsecureSkipVerify = true
-	}
-
-	return tlsConfig, nil
-}
-
-// Hostname implements the config.Provider interface.
-func (n *NetworkConfig) Hostname() string {
-	return n.NetworkHostname
-}
-
-// DisableSearchDomain implements the config.Provider interface.
-func (n *NetworkConfig) DisableSearchDomain() bool {
-	return pointer.SafeDeref(n.NetworkDisableSearchDomain)
-}
-
 // Devices implements the config.Provider interface.
 func (n *NetworkConfig) Devices() []config.Device {
 	return xslices.Map(n.NetworkInterfaces, func(d *Device) config.Device { return d })
@@ -616,19 +591,9 @@ func (n *NetworkConfig) getDevice(iface IfaceSelector) *Device {
 	return dev
 }
 
-// Resolvers implements the config.Provider interface.
-func (n *NetworkConfig) Resolvers() []string {
-	return n.NameServers
-}
-
-// SearchDomains implements the config.Provider interface.
-func (n *NetworkConfig) SearchDomains() []string {
-	return n.Searches
-}
-
 // ExtraHosts implements the config.Provider interface.
-func (n *NetworkConfig) ExtraHosts() []config.ExtraHost {
-	return xslices.Map(n.ExtraHostEntries, func(e *ExtraHost) config.ExtraHost { return e })
+func (n *NetworkConfig) ExtraHosts() []config.NetworkStaticHostConfig {
+	return xslices.Map(n.ExtraHostEntries, func(e *ExtraHost) config.NetworkStaticHostConfig { return e })
 }
 
 // KubeSpan implements the config.Provider interface.
@@ -1178,6 +1143,11 @@ func (v *Vlan) ID() uint16 {
 	return v.VlanID
 }
 
+// Mode implements the MachineNetwork interface.
+func (v *Vlan) Mode() nethelpers.VLANProtocol {
+	return nethelpers.VLANProtocol8021Q
+}
+
 // Enabled implements KubeSpan interface.
 func (k *NetworkKubeSpan) Enabled() bool {
 	return pointer.SafeDeref(k.KubeSpanEnabled)
@@ -1222,6 +1192,27 @@ func (k *KubeSpanFilters) Endpoints() []string {
 	return k.KubeSpanFiltersEndpoints
 }
 
+// ExcludeAdvertisedNetworks implements the config.KubeSpanFilters interface.
+func (k *KubeSpanFilters) ExcludeAdvertisedNetworks() []netip.Prefix {
+	if len(k.KubeSpanFiltersExcludeAdvertisedNetworks) == 0 {
+		return nil
+	}
+
+	result := make([]netip.Prefix, 0, len(k.KubeSpanFiltersExcludeAdvertisedNetworks))
+
+	for _, cidrStr := range k.KubeSpanFiltersExcludeAdvertisedNetworks {
+		// prefixes are validated, so for defensive programming, we can ignore errors here.
+		prefix, err := netip.ParsePrefix(cidrStr)
+		if err != nil {
+			continue
+		}
+
+		result = append(result, prefix)
+	}
+
+	return result
+}
+
 // Disabled implements the config.Provider interface.
 func (t *TimeConfig) Disabled() bool {
 	return pointer.SafeDeref(t.TimeDisabled)
@@ -1436,6 +1427,11 @@ func (i *InstallConfig) LegacyBIOSSupport() bool {
 	return pointer.SafeDeref(i.InstallLegacyBIOSSupport)
 }
 
+// GrubUseUKICmdline implements the config.Provider interface.
+func (i *InstallConfig) GrubUseUKICmdline() bool {
+	return pointer.SafeDeref(i.InstallGrubUseUKICmdline)
+}
+
 // Image implements the config.Provider interface.
 func (i InstallExtensionConfig) Image() string {
 	return i.ExtensionImage
@@ -1629,6 +1625,18 @@ func (e *EncryptionKeyTPM) CheckSecurebootOnEnroll() bool {
 	return pointer.SafeDeref(e.TPMCheckSecurebootStatusOnEnroll)
 }
 
+// PCRs implements the config.Provider interface.
+func (e *EncryptionKeyTPM) PCRs() []int {
+	// v1alpha1 always used PCR 7
+	return []int{constants.SecureBootStatePCR}
+}
+
+// PubKeyPCRs implements the config.Provider interface.
+func (e *EncryptionKeyTPM) PubKeyPCRs() []int {
+	// we always lock to PCR 11
+	return []int{constants.UKIPCR}
+}
+
 // Slot implements the config.Provider interface.
 func (e *EncryptionKey) Slot() int {
 	return e.KeySlot
