@@ -13,9 +13,9 @@ migrated to their own documents.
 */
 package v1alpha1
 
-//go:generate docgen -output ./v1alpha1_types_doc.go ./v1alpha1_types.go
+//go:generate go tool github.com/siderolabs/talos/tools/docgen -output ./v1alpha1_types_doc.go ./v1alpha1_types.go
 
-//go:generate deepcopy-gen --go-header-file ../../../../../hack/boilerplate.txt --bounding-dirs ../v1alpha1 --output-file zz_generated.deepcopy
+//go:generate go tool k8s.io/code-generator/cmd/deepcopy-gen --go-header-file ../../../../../hack/boilerplate.txt --bounding-dirs ../v1alpha1 --output-file zz_generated.deepcopy
 
 //docgen:jsonschema
 
@@ -30,7 +30,7 @@ import (
 
 	"github.com/dustin/go-humanize"
 	"github.com/siderolabs/crypto/x509"
-	"gopkg.in/yaml.v3"
+	"go.yaml.in/yaml/v4"
 
 	"github.com/siderolabs/talos/pkg/machinery/config/config"
 	"github.com/siderolabs/talos/pkg/machinery/config/internal/registry"
@@ -171,9 +171,6 @@ type MachineConfig struct {
 	MachinePods []Unstructured `yaml:"pods,omitempty"`
 	//   description: |
 	//     Provides machine specific network configuration options.
-	//   examples:
-	//     - name: Network definition example.
-	//       value: machineNetworkConfigExample()
 	MachineNetwork *NetworkConfig `yaml:"network,omitempty"`
 	// docgen:nodoc
 	//
@@ -219,11 +216,9 @@ type MachineConfig struct {
 	//       ".*":
 	//         type: string
 	MachineEnv Env `yaml:"env,omitempty"`
-	//   description: |
-	//     Used to configure the machine's time settings.
-	//   examples:
-	//     - name: Example configuration for cloudflare ntp server.
-	//       value: machineTimeExample()
+	// docgen:nodoc
+	//
+	// Deprecated: Use 'TimeSyncConfig' instead.
 	MachineTime *TimeConfig `yaml:"time,omitempty"`
 	//   description: |
 	//     Used to configure the machine's sysctls.
@@ -237,21 +232,9 @@ type MachineConfig struct {
 	//     - name: MachineSysfs usage example.
 	//       value: machineSysfsExample()
 	MachineSysfs map[string]string `yaml:"sysfs,omitempty"`
-	//   description: |
-	//     Used to configure the machine's container image registry mirrors.
+	// docgen:nodoc
 	//
-	//     Automatically generates matching CRI configuration for registry mirrors.
-	//
-	//     The `mirrors` section allows to redirect requests for images to a non-default registry,
-	//     which might be a local registry or a caching mirror.
-	//
-	//     The `config` section provides a way to authenticate to the registry with TLS client
-	//     identity, provide registry CA, or authentication information.
-	//     Authentication information has same meaning with the corresponding field in [`.docker/config.json`](https://docs.docker.com/engine/api/v1.41/#section/Authentication).
-	//
-	//     See also matching configuration for [CRI containerd plugin](https://github.com/containerd/cri/blob/master/docs/registry.md).
-	//   examples:
-	//     - value: machineConfigRegistriesExample()
+	// Deprecated: Use `Registry*Config` instead.
 	MachineRegistries RegistriesConfig `yaml:"registries,omitempty"`
 	// docgen:nodoc
 	//
@@ -692,52 +675,40 @@ type KubeletNodeIPConfig struct {
 
 // NetworkConfig represents the machine's networking config values.
 type NetworkConfig struct {
-	//   description: |
-	//     Used to statically set the hostname for the machine.
+	// docgen:nodoc
+	//
+	// Deprecated: use `HostnameConfig` instead.
 	NetworkHostname string `yaml:"hostname,omitempty"`
-	//   description: |
-	//     `interfaces` is used to define the network interface configuration.
-	//     By default all network interfaces will attempt a DHCP discovery.
-	//     This can be further tuned through this configuration parameter.
-	//   examples:
-	//     - value: machineNetworkConfigExample().NetworkInterfaces
+	// docgen:nodoc
+	//
+	// Deprecated: use multi-doc network config.
 	NetworkInterfaces NetworkDeviceList `yaml:"interfaces,omitempty"`
-	//   description: |
-	//     Used to statically set the nameservers for the machine.
-	//     Defaults to `1.1.1.1` and `8.8.8.8`
-	//   examples:
-	//     - value: '[]string{"8.8.8.8", "1.1.1.1"}'
+	// docgen:nodoc
+	//
+	// Deprecated: Use `ResolverConfig` instead.
 	NameServers []string `yaml:"nameservers,omitempty"`
-	//   description: |
-	//     Used to statically set arbitrary search domains.
-	//   examples:
-	//     - value: '[]string{"example.org", "example.com"}'
+	// docgen:nodoc
+	//
+	// Deprecated: Use `ResolverConfig` instead.
 	Searches []string `yaml:"searchDomains,omitempty"`
-	//   description: |
-	//     Allows for extra entries to be added to the `/etc/hosts` file
-	//   examples:
-	//     - value: networkConfigExtraHostsExample()
+	// docgen:nodoc
+	//
+	// Deprecated: Use `StatisHostConfig` instead.
 	ExtraHostEntries []*ExtraHost `yaml:"extraHostEntries,omitempty"`
 	//   description: |
 	//     Configures KubeSpan feature.
 	//   examples:
 	//     - value: networkKubeSpanExample()
 	NetworkKubeSpan *NetworkKubeSpan `yaml:"kubespan,omitempty"`
-	//   description: |
-	//     Disable generating a default search domain in /etc/resolv.conf
-	//     based on the machine hostname.
-	//     Defaults to `false`.
-	//   values:
-	//     - true
-	//     - yes
-	//     - false
-	//     - no
+	// docgen:nodoc
+	//
+	// Deprecated: Use `ResolverConfig` instead.
 	NetworkDisableSearchDomain *bool `yaml:"disableSearchDomain,omitempty"`
 }
 
 // NetworkDeviceList is a list of *Device structures with overridden merge process.
 //
-//docgen:alias
+// docgen:nodoc
 type NetworkDeviceList []*Device
 
 // Merge the network interface configuration intelligently.
@@ -801,13 +772,9 @@ type InstallConfig struct {
 	//   examples:
 	//     - value: machineInstallDiskSelectorExample()
 	InstallDiskSelector *InstallDiskSelector `yaml:"diskSelector,omitempty"`
-	//   description: |
-	//     Allows for supplying extra kernel args via the bootloader.
-	//     Existing kernel args can be removed by prefixing the argument with a `-`.
-	//     For example `-console` removes all `console=<value>` arguments, whereas `-console=tty0` removes the `console=tty0` default argument.
-	//     If Talos is using systemd-boot as a bootloader (default for UEFI) this setting will be ignored.
-	//   examples:
-	//     - value: '[]string{"talos.platform=metal", "reboot=k"}'
+	// docgen:nodoc
+	//
+	// Deprecated: Use Image Factory/imager instead to build a proper installer.
 	InstallExtraKernelArgs []string `yaml:"extraKernelArgs,omitempty"`
 	//   description: |
 	//     Allows for supplying the image used to perform the installation.
@@ -837,6 +804,10 @@ type InstallConfig struct {
 	//     Indicates if MBR partition should be marked as bootable (active).
 	//     Should be enabled only for the systems with legacy BIOS that doesn't support GPT partitioning scheme.
 	InstallLegacyBIOSSupport *bool `yaml:"legacyBIOSSupport,omitempty"`
+	//   description: |
+	//     Indicates if legacy GRUB bootloader should use kernel cmdline from the UKI instead of building it on the host.
+	//     This changes the way cmdline is managed with GRUB bootloader to be more consistent with UKI/systemd-boot.
+	InstallGrubUseUKICmdline *bool `yaml:"grubUseUKICmdline,omitempty"`
 }
 
 // InstallDiskSizeMatcher disk size condition parser.
@@ -948,6 +919,8 @@ type InstallExtensionConfig struct {
 }
 
 // TimeConfig represents the options for configuring time on a machine.
+//
+//docgen:nodoc
 type TimeConfig struct {
 	//   description: |
 	//     Indicates if the time service is disabled for the machine.
@@ -971,6 +944,8 @@ type TimeConfig struct {
 }
 
 // RegistriesConfig represents the image pull options.
+//
+// docgen:nodoc
 type RegistriesConfig struct {
 	//   description: |
 	//     Specifies mirror configuration for each registry host namespace.
@@ -984,8 +959,6 @@ type RegistriesConfig struct {
 	//
 	//     Registry name is the first segment of image identifier, with 'docker.io'
 	//     being default one.
-	//   examples:
-	//     - value: machineConfigRegistryMirrorsExample()
 	RegistryMirrors map[string]*RegistryMirrorConfig `yaml:"mirrors,omitempty"`
 	//   description: |
 	//     Specifies TLS & auth configuration for HTTPS image registries.
@@ -997,8 +970,6 @@ type RegistriesConfig struct {
 	//
 	//     TLS configuration can be skipped if registry has trusted
 	//     server certificate.
-	//   examples:
-	//     - value: machineConfigRegistryConfigExample()
 	RegistryConfig map[string]*RegistryConfig `yaml:"config,omitempty"`
 }
 
@@ -1118,8 +1089,7 @@ type APIServerConfig struct {
 	//   description: |
 	//     Extra certificate subject alternative names for the API server's certificate.
 	CertSANs []string `yaml:"certSANs,omitempty"`
-	//   description: |
-	//     Disable PodSecurityPolicy in the API server and default manifests.
+	// docgen:nodoc
 	DisablePodSecurityPolicyConfig *bool `yaml:"disablePodSecurityPolicy,omitempty"`
 	//   description: |
 	//     Configure the API server admission plugins.
@@ -1705,6 +1675,8 @@ type MachineFile struct {
 }
 
 // ExtraHost represents a host entry in /etc/hosts.
+//
+// docgen:nodoc
 type ExtraHost struct {
 	//   description: The IP of the host.
 	HostIP string `yaml:"ip"`
@@ -1713,6 +1685,8 @@ type ExtraHost struct {
 }
 
 // Device represents a network interface.
+//
+// docgen:nodoc
 type Device struct {
 	//   description: |
 	//     The interface name.
@@ -1805,6 +1779,8 @@ type Device struct {
 }
 
 // DHCPOptions contains options for configuring the DHCP settings for a given interface.
+//
+// docgen:nodoc
 type DHCPOptions struct {
 	//   description: The priority of all routes received via DHCP.
 	DHCPRouteMetric uint32 `yaml:"routeMetric"`
@@ -1817,6 +1793,8 @@ type DHCPOptions struct {
 }
 
 // DeviceWireguardConfig contains settings for configuring Wireguard network interface.
+//
+// docgen:nodoc
 type DeviceWireguardConfig struct {
 	//   description: |
 	//     Specifies a private key configuration (base64 encoded).
@@ -1831,6 +1809,8 @@ type DeviceWireguardConfig struct {
 }
 
 // DeviceWireguardPeer a WireGuard device peer configuration.
+//
+// docgen:nodoc
 type DeviceWireguardPeer struct {
 	//   description: |
 	//     Specifies the public key of this peer.
@@ -1850,6 +1830,8 @@ type DeviceWireguardPeer struct {
 }
 
 // DeviceVIPConfig contains settings for configuring a Virtual Shared IP on an interface.
+//
+// docgen:nodoc
 type DeviceVIPConfig struct {
 	// description: Specifies the IP address to be used.
 	SharedIP string `yaml:"ip,omitempty"`
@@ -1860,18 +1842,24 @@ type DeviceVIPConfig struct {
 }
 
 // VIPEquinixMetalConfig contains settings for Equinix Metal VIP management.
+//
+// docgen:nodoc
 type VIPEquinixMetalConfig struct {
 	// description: Specifies the Equinix Metal API Token.
 	EquinixMetalAPIToken string `yaml:"apiToken"`
 }
 
 // VIPHCloudConfig contains settings for Hetzner Cloud VIP management.
+//
+// docgen:nodoc
 type VIPHCloudConfig struct {
 	// description: Specifies the Hetzner Cloud API Token.
 	HCloudAPIToken string `yaml:"apiToken"`
 }
 
 // Bond contains the various options for configuring a bonded interface.
+//
+// docgen:nodoc
 type Bond struct {
 	//   description: The interfaces that make up the bond.
 	BondInterfaces []string `yaml:"interfaces"`
@@ -1992,18 +1980,24 @@ type Bond struct {
 }
 
 // STP contains the various options for configuring the STP properties of a bridge interface.
+//
+// docgen:nodoc
 type STP struct {
 	//   description: Whether Spanning Tree Protocol (STP) is enabled.
 	STPEnabled *bool `yaml:"enabled,omitempty"`
 }
 
 // BridgeVLAN contains the various options for configuring the VLAN properties of a bridge interface.
+//
+// docgen:nodoc
 type BridgeVLAN struct {
 	//   description: Whether VLAN filtering is enabled.
 	BridgeVLANFiltering *bool `yaml:"vlanFiltering,omitempty"`
 }
 
 // Bridge contains the various options for configuring a bridge interface.
+//
+// docgen:nodoc
 type Bridge struct {
 	//   description: The interfaces that make up the bridge.
 	BridgedInterfaces []string `yaml:"interfaces"`
@@ -2018,6 +2012,8 @@ type Bridge struct {
 }
 
 // BridgePort contains settings for assigning a link to a bridge interface.
+//
+// docgen:nodoc
 type BridgePort struct {
 	//   description: The name of the bridge master interface
 	BridgePortMaster string `yaml:"master,omitempty"`
@@ -2025,7 +2021,7 @@ type BridgePort struct {
 
 // VlanList is a list of *Vlan structures with overridden merge process.
 //
-//docgen:alias
+// docgen:nodoc
 type VlanList []*Vlan
 
 // Merge the network interface configuration intelligently.
@@ -2065,6 +2061,8 @@ func (vlans *VlanList) mergeVlan(vlan *Vlan) error {
 }
 
 // Vlan represents vlan settings for a device.
+//
+// docgen:nodoc
 type Vlan struct {
 	//   description: The addresses in CIDR notation or as plain IPs to use.
 	VlanAddresses []string `yaml:"addresses,omitempty"`
@@ -2087,6 +2085,8 @@ type Vlan struct {
 }
 
 // Route represents a network route.
+//
+// docgen:nodoc
 type Route struct {
 	//   description: The route's network (destination).
 	RouteNetwork string `yaml:"network"`
@@ -2101,6 +2101,8 @@ type Route struct {
 }
 
 // RegistryMirrorConfig represents mirror configuration for a registry.
+//
+// docgen:nodoc
 type RegistryMirrorConfig struct {
 	//   description: |
 	//     List of endpoints (URLs) for registry mirrors to use.
@@ -2119,6 +2121,8 @@ type RegistryMirrorConfig struct {
 }
 
 // RegistryConfig specifies auth & TLS config per registry.
+//
+// docgen:nodoc
 type RegistryConfig struct {
 	//   description: |
 	//     The TLS configuration for the registry.
@@ -2135,6 +2139,8 @@ type RegistryConfig struct {
 }
 
 // RegistryAuthConfig specifies authentication configuration for a registry.
+//
+// docgen:nodoc
 type RegistryAuthConfig struct {
 	//   description: |
 	//     Optional registry authentication.
@@ -2155,6 +2161,8 @@ type RegistryAuthConfig struct {
 }
 
 // RegistryTLSConfig specifies TLS config for HTTPS registries.
+//
+// docgen:nodoc
 type RegistryTLSConfig struct {
 	//   description: |
 	//     Enable mutual TLS authentication with the registry.
@@ -2197,11 +2205,11 @@ var _ config.Features = (*FeaturesConfig)(nil)
 
 // FeaturesConfig describes individual Talos features that can be switched on or off.
 type FeaturesConfig struct {
-	//   description: |
-	//     Enable role-based access control (RBAC).
+	// docgen:nodoc
 	RBAC *bool `yaml:"rbac,omitempty"`
-	//   description: |
-	//     Enable stable default hostname.
+	// docgen:nodoc
+	//
+	// Deprecated: use HostConfig instead.
 	StableHostname *bool `yaml:"stableHostname,omitempty"`
 	//   description: |
 	//    Configure Talos API access from Kubernetes pods.
@@ -2210,8 +2218,7 @@ type FeaturesConfig struct {
 	//   examples:
 	//     - value: kubernetesTalosAPIAccessConfigExample()
 	KubernetesTalosAPIAccessConfig *KubernetesTalosAPIAccessConfig `yaml:"kubernetesTalosAPIAccess,omitempty"`
-	//   description: |
-	//     Enable checks for extended key usage of client certificates in apid.
+	// docgen:nodoc
 	ApidCheckExtKeyUsage *bool `yaml:"apidCheckExtKeyUsage,omitempty"`
 	//   description: |
 	//     Enable XFS project quota support for EPHEMERAL partition and user disks.
@@ -2391,9 +2398,25 @@ type KubeSpanFilters struct {
 	//   - name: Exclude addresses in 192.168.0.0/16 subnet.
 	//     value: '[]string{"0.0.0.0/0", "!192.168.0.0/16", "::/0"}'
 	KubeSpanFiltersEndpoints []string `yaml:"endpoints,omitempty"`
+	// description: |
+	//   Filter networks (e.g., host addresses, pod CIDRs if enabled) which will be advertised over KubeSpan.
+	//
+	//   By default, all networks are advertised.
+	//   Use this filter to exclude some networks from being advertised.
+	//
+	//   Note: excluded networks will not be reachable over KubeSpan, so make sure
+	//   these networks are still reachable via some other route (e.g., direct connection).
+	//
+	//   Default value: no filtering.
+	// examples:
+	//   - name: Exclude private networks from being advertised.
+	//     value: '[]string{"172.16.0.0/12"}'
+	KubeSpanFiltersExcludeAdvertisedNetworks []string `yaml:"excludeAdvertisedNetworks,omitempty"`
 }
 
 // NetworkDeviceSelector struct describes network device selector.
+//
+// docgen:nodoc
 type NetworkDeviceSelector struct {
 	// description: PCI, USB bus prefix, supports matching by wildcard.
 	NetworkDeviceBus string `yaml:"busPath,omitempty"`
