@@ -11,6 +11,7 @@ import (
 	"errors"
 	"fmt"
 	"net"
+	"net/netip"
 	"net/url"
 	"os"
 	"reflect"
@@ -109,6 +110,10 @@ func (c *Config) Validate(mode validation.RuntimeMode, options ...validation.Opt
 			if c.MachineConfig.MachineInstall.InstallDisk == "" && matcher == nil {
 				result = multierror.Append(result, errors.New("either install disk or diskSelector should be defined"))
 			}
+
+			if len(c.MachineConfig.MachineInstall.InstallExtraKernelArgs) > 0 && c.MachineConfig.MachineInstall.GrubUseUKICmdline() {
+				result = multierror.Append(result, errors.New("install.extraKernelArgs and install.grubUseUKICmdline can't be used together"))
+			}
 		}
 	}
 
@@ -277,7 +282,16 @@ func (c *Config) Validate(mode validation.RuntimeMode, options ...validation.Opt
 			cidr = strings.TrimPrefix(cidr, "!")
 
 			if _, err := sideronet.ParseSubnetOrAddress(cidr); err != nil {
-				result = multierror.Append(result, fmt.Errorf("KubeSpan endpoint filer is not valid: %q", cidr))
+				result = multierror.Append(result, fmt.Errorf("KubeSpan endpoint filter is not valid: %q", cidr))
+			}
+		}
+
+		if c.MachineConfig.MachineNetwork.NetworkKubeSpan.KubeSpanFilters != nil {
+			for _, cidr := range c.MachineConfig.MachineNetwork.NetworkKubeSpan.KubeSpanFilters.KubeSpanFiltersExcludeAdvertisedNetworks {
+				_, err := netip.ParsePrefix(cidr)
+				if err != nil {
+					result = multierror.Append(result, fmt.Errorf("KubeSpan exclude advertised networks filter is not valid: %q", cidr))
+				}
 			}
 		}
 	}
@@ -316,10 +330,6 @@ func (c *Config) Validate(mode validation.RuntimeMode, options ...validation.Opt
 	}
 
 	if c.Machine().Features().KubernetesTalosAPIAccess().Enabled() {
-		if !c.Machine().Features().RBACEnabled() {
-			result = multierror.Append(result, errors.New("feature API RBAC should be enabled when Kubernetes Talos API Access feature is enabled"))
-		}
-
 		if !c.Machine().Type().IsControlPlane() {
 			result = multierror.Append(result, errors.New("feature Kubernetes Talos API Access can only be enabled on control plane machines"))
 		}
