@@ -5,15 +5,17 @@
 package qemu
 
 import (
+	"errors"
 	"fmt"
 	"io"
+	"io/fs"
 	"os"
 
-	"github.com/siderolabs/talos/pkg/provision/providers/vm"
+	"github.com/siderolabs/talos/pkg/provision"
 )
 
 //nolint:gocyclo
-func (p *provisioner) createPFlashImages(state *vm.State, nodeName string, pflashSpec []PFlash) ([]string, error) {
+func (p *provisioner) createPFlashImages(state *provision.State, nodeName string, pflashSpec []PFlash) ([]string, error) {
 	var images []string
 
 	for i, pflash := range pflashSpec {
@@ -37,7 +39,7 @@ func (p *provisioner) createPFlashImages(state *vm.State, nodeName string, pflas
 
 					src, err = os.Open(sourcePath)
 					if err != nil {
-						if os.IsNotExist(err) {
+						if errors.Is(err, fs.ErrNotExist) {
 							continue
 						}
 
