@@ -8,24 +8,29 @@ package provision
 import (
 	"context"
 
+	"github.com/siderolabs/talos/pkg/machinery/config"
+	"github.com/siderolabs/talos/pkg/machinery/config/bundle"
 	"github.com/siderolabs/talos/pkg/machinery/config/generate"
 	"github.com/siderolabs/talos/pkg/machinery/config/types/v1alpha1"
 )
 
 // Provisioner is an interface each provisioner should implement.
+//
+//nolint:interfacebloat
 type Provisioner interface {
 	Create(context.Context, ClusterRequest, ...Option) (Cluster, error)
 	Destroy(context.Context, Cluster, ...Option) error
 
 	Reflect(ctx context.Context, clusterName, stateDirectory string) (Cluster, error)
 
-	GenOptions(NetworkRequest) []generate.Option
+	GenOptions(NetworkRequest, *config.VersionContract) ([]generate.Option, []bundle.Option)
 
 	GetInClusterKubernetesControlPlaneEndpoint(req NetworkRequest, controlPlanePort int) string
 	GetExternalKubernetesControlPlaneEndpoint(req NetworkRequest, controlPlanePort int) string
 	GetTalosAPIEndpoints(NetworkRequest) []string
 
 	GetFirstInterface() v1alpha1.IfaceSelector
+	GetFirstInterfaceName() string
 
 	Close() error
 
